@@ -3,4 +3,4 @@
 
 GtkWidget * mtm_view_extensions_new (MtmSelector *selector);
 
-#endif __MTM_VIEW_EXTENSIONS_H__
+#endif /* __MTM_VIEW_EXTENSIONS_H__ */
