@@ -27,7 +27,7 @@ struct _EditorMainPageClass
 	EditorPageClass parent_class;
 };
 
-GtkType editor_main_page_get_type (void);
+GType editor_main_page_get_type (void);
 
 GtkWidget* editor_main_page_new (MtmTheme *theme, GtkWidget *parent_window);
 
