@@ -27,7 +27,7 @@ struct _HandlerManagerClass
 	GtkObjectClass parent_class;
 };
 
-GtkType handler_manager_get_type (void);
+GType handler_manager_get_type (void);
 HandlerManager* handler_manager_new (void);
 
 void handler_manager_add (HandlerManager *hm, gchar *type, MtmHandler *handler);
