@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  *
- * Authors: Richard Hestilow <tvgm@ximian.com>
+ * Authors: Rachel Hestilow <hestilow@ximian.com>
  *
  */
 
@@ -38,6 +38,9 @@
 
 #define GLADEFILE (SHAREDIR "bg-config-gui.glade")
 
+#define PREVIEW_WIDTH 256
+#define PREVIEW_HEIGHT 192
+
 typedef struct 
 {
 	MtmExt *ext;
@@ -305,7 +308,7 @@ bg_config_gui_new (MtmGuiHandler *handler)
 	preview->xml = xml;
 	preview->ext = NULL;
 	preview->realized = FALSE;
-	preview->applier = BG_APPLIER (bg_applier_new (BG_APPLIER_PREVIEW));
+	preview->applier = BG_APPLIER (bg_applier_new_at_size (BG_APPLIER_PREVIEW, PREVIEW_WIDTH, PREVIEW_HEIGHT));
 
 	w = glade_xml_get_widget (xml, "preview_frame");
 	gtk_container_add (GTK_CONTAINER (w), bg_applier_get_preview_widget (preview->applier));
